@@ -36,24 +36,29 @@ photo = None
 able_to_listen = True
 
 class MailFolder:
-	def __init__(self, foldername):
+	def __init__(self, foldername, foldertype):
 		self.foldername = foldername
 		self.folders = []
 		self.name = foldername.split("__")[0]
 		self.domain = foldername.split("__")[1].replace("_", ":")
 		self.messages = []
+		self.type = foldertype
 	def check(self):
-		messages = os.listdir('/home/user/.modest/cache/mail/imap/'+self.foldername+'/folders/INBOX/')
-		unread = []
-		for i in messages:
-			if not i in self.messages:
-				unread.append(email.message_from_file(open('/home/user/.modest/cache/mail/imap/'+self.foldername+'/folders/INBOX/'+i)))
-		self.messages = messages
-		return unread
+		try:
+			messages = os.listdir('/home/user/.modest/cache/mail/'+self.foldertype+'/'+self.foldername+'/folders/INBOX/')
+			unread = []
+			for i in messages:
+				if not i in self.messages:
+					unread.append(email.message_from_file(open('/home/user/.modest/cache/mail/'+self.foldertype+'/'+self.foldername+'/folders/INBOX/'+i)))
+			self.messages = messages
+			return unread
+		except OSError:
+			return []
 
 class Saera:
 	def __init__(self):
-		self.mailfolders = []
+		self.imap_mailfolders = []
+		self.pop_mailfolders = []
 		self.ims = []
 		self.lines = [['What can I help you with?',False]]
 		try:
@@ -227,7 +232,9 @@ class Saera:
 	def check_mail(self):
 		self.pipeline.set_state(gst.STATE_PAUSED)
 		result = []
-		for i in self.mailfolders:
+		for i in self.imap_mailfolders:
+			result = result + i.check()
+		for i in self.pop_mailfolders:
 			result = result + i.check()
 		if result:
 			# for j in result:
@@ -420,14 +427,25 @@ class Saera:
 		self.darea.queue_draw()
 
 	def init_mail(self):
-		mailfolder = '/home/user/.modest/cache/mail/imap/'
-		accounts = os.listdir(mailfolder)
-		for i in accounts:
-			folder = MailFolder(i)
-			folder.folders = os.listdir(mailfolder+i+'/folders')
-			if "INBOX" in folder.folders:
-				folder.messages = os.listdir(mailfolder+i+'/folders/INBOX/')
-			self.mailfolders.append(folder)
+		try:
+			imap_mailfolder = '/home/user/.modest/cache/mail/imap/'
+			accounts = os.listdir(imap_mailfolder)
+			for i in accounts:
+				folder = MailFolder(i, 'imap')
+				folder.folders = os.listdir(imap_mailfolder+i+'/folders')
+				if "INBOX" in folder.folders:
+					folder.messages = os.listdir(imap_mailfolder+i+'/folders/INBOX/')
+				self.imap_mailfolders.append(folder)
+			pop_mailfolder = '/home/user/.modest/cache/mail/pop/'
+			accounts = os.listdir(pop_mailfolder)
+			for i in accounts:
+				folder = MailFolder(i,'pop')
+				folder.folders = os.listdir(pop_mailfolder+i+'/folders')
+				if "INBOX" in folder.folders:
+					folder.messages = os.listdir(pop_mailfolder+i+'/folders/INBOX/')
+				self.pop_mailfolders.append(folder)
+		except OSError:
+			pass
 
 
 	def init_gst(self):
